# Tesseral Flask SDK

[![pypi](https://img.shields.io/pypi/v/tesseral-fastapi)](https://pypi.python.org/pypi/tesseral-fastapi)

`tesseral_flask` is the official Tesseral SDK for FastAPI.

Documentation for this package is available [here](https://tesseral.com/docs/sdks/serverside-sdks/tesseral-sdk-fastapi).
